@@ -30,8 +30,14 @@ def runpy(args: List[str]) -> None:
 
 def hold(args: List[str]) -> None:
     import subprocess
+    from contextlib import suppress
+    import tty
     ret = subprocess.Popen(args[1:]).wait()
-    sys.stdin.read()
+    with suppress(BaseException):
+        print('\n\x1b[1;32mPress any key to exit', end='', flush=True)
+    with suppress(BaseException):
+        tty.setraw(sys.stdin.fileno())
+        sys.stdin.buffer.read(1)
     raise SystemExit(ret)
 
 
@@ -65,6 +71,11 @@ def run_kitten(args: List[str]) -> None:
     rk(kitten)
 
 
+def edit_config_file(args: List[str]) -> None:
+    from kitty.utils import edit_config_file as f
+    f()
+
+
 def namespaced(args: List[str]) -> None:
     func = namespaced_entry_points[args[1]]
     func(args[1:])
@@ -77,6 +88,7 @@ entry_points = {
     'runpy': runpy,
     'launch': launch,
     'kitten': run_kitten,
+    'edit-config': edit_config_file,
 
     '@': remote_control,
     '+': namespaced,
